Learn R Programming

knfi (version 1.0.0)

col_name: The Korean and English names of the column names

Description

The Korean and English names of the column names

Usage

col_name

Arguments

Format

An object of class data.frame with 174 rows and 3 columns.