Learn R Programming

knfi (version 1.0.2)

switchcol_nfi: Switch column names

Description

The switchcol_nfi() function allows switching between the original Korean column names and English column names. If the input data has English column names, it changes them to the original Korean names, and vice versa.

Usage

switchcol_nfi(data)

Value

A list of dataframes with switched column names.

Arguments

data

: A list generated by read_nfi.

Details

Important: Data with original Korean column names cannot be used with any read_nfi functions except switchcol_nfi() itself. The option to revert to original Korean names is provided solely for users who wish to store or process the NFI data with original column names.

Examples

Run this code

data("nfi_donghae")

#Switch column names from English to original Korean names
nfi_donghae_kor <- switchcol_nfi(nfi_donghae)

# Switch column names from original Korean to English names
nfi_donghae_eng <- switchcol_nfi(nfi_donghae_kor)

Run the code above in your browser using DataLab