- data
: A list generated by read_nfi that contains 'plot' and 'tree' data frames.
- y
: A character vector; the variable to visualize. Must be one of 'biomass', 'cwd', 'iv'.
- bm_type
: A character vector; the specific variable to visualize for 'biomass' or 'cwd'. Must be one of 'volume', 'biomass', 'AG_biomass', 'carbon', 'co2'.
- output
: A character vector; the desired type of visualization. Must be one of 'table', 'line', 'bar', 'map'.
- plotgrp
: A character vector; specifies variables from the 'plot' table to use for grouping. Use c() to combine multiple variables, but if the output is a map, line or bar plot, only one variable can be used.
- treegrp
: A character vector; variables from 'tree' tables for grouping. Use c() to combine multiple variables.
- isannual
: A logical flag (default TRUE); if TRUE, the result is provided annually, if FALSE, it is provided in 5-year intervals.
- continuousplot
: A logical flag (default TRUE); if TRUE, includes only plots that have been measured at the exact same location across all NFI cycles (5th, 6th, etc.). If FALSE, includes all plots regardless of location changes or missing cycle measurements.
- admin
: A character vector; the administrative unit for visualizing 'biomass' or 'cwd' as a map. Must be one of 'sido', 'sgg', 'emd'.
- strat
: A character vector; the variable used for post-stratification. In the National Forest Inventory of Korea, it is typically used by forest type.
- clusterplot
: A logical flag (default FALSE); if TRUE, treats each cluster plot as a single unit. If FALSE, calculates for each subplot separately.
- largetreearea
: A logical flag (default FALSE); if TRUE, includes large tree survey plots in the analysis. If FALSE, only uses standard tree plots.
- stockedland
: A logical flag (default TRUE); if TRUE, includes only stocked land. If FALSE, includes all land types.
- talltree
: A logical flag (default TRUE); if TRUE, includes only tall trees. If FALSE, includes both trees and shrubs.
- sp
: A character vector; the column name of species information (e.g., "SP" for species, "GENUS" for genus-level analysis).
- frequency
: A logical flag (default TRUE); if TRUE, includes frequency in importance value calculations.
- ncol
: A numeric vector (default NULL); Number of columns in the grid layout when faceting by plotgrp.
- nrow
: A numeric vector (default NULL); Number of columns in the grid layout when faceting by plotgrp.
- top
: A numeric vector (default 20); Number of top species to display in 'iv' plot